'use strict';

exports.__esModule = true;

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

exports.default = function (babel) {
  var t = babel.types;

  // converts
  // <svg stroke-width="5">
  // to
  // <svg strokeWidth="5">
  var hyphenToCamelVisitor = {
    JSXAttribute: function JSXAttribute(path) {
      path.node.name.name = (0, _hyphenToCamel2.default)(path.node.name.name);
    }
  };

  // converts
  // <tag style="text-align: center; width: 50px">
  // to
  // <tag style={{textAlign: 'center', width: '50px'}}>
  var styleAttrVisitor = {
    JSXAttribute: function JSXAttribute(path) {
      if (path.node.name.name === 'style') {
        var _ret = function () {
          var csso = (0, _cssToObj2.default)(path.node.value.value);
          var properties = Object.keys(csso).map(function (prop) {
            return t.objectProperty(t.identifier((0, _hyphenToCamel2.default)(prop)), t.stringLiteral(csso[prop]));
          });
          path.node.value = t.jSXExpressionContainer(t.objectExpression(properties));
          return {
            v: void 0
          };
        }();

        if ((typeof _ret === 'undefined' ? 'undefined' : _typeof(_ret)) === "object") return _ret.v;
      }
    }
  };

  // Flow props from Output component to root SVG
  // converts
  // <svg width="50">
  // to
  // <svg width={this.props.width ? this.props.width : "50"}>
  var attrVisitor = {
    JSXAttribute: function JSXAttribute(path) {
      if (!t.isJSXIdentifier(path.node.name)) return;
      // don't handle style attr. It needs to be an object
      if (path.node.name.name === 'style') return;

      // else
      var valueExpression = t.memberExpression(t.memberExpression(t.thisExpression(), t.identifier('props')), t.identifier((0, _hyphenToCamel2.default)(path.node.name.name)));

      path.node.value = t.jSXExpressionContainer(t.conditionalExpression(valueExpression, valueExpression, t.stringLiteral(path.node.value.value)));
    }
  };

  // converts
  // <svg>
  // to
  // <svg {...this.props}>
  // after passing through attributes visitors
  var svgVisitor = {
    JSXOpeningElement: function JSXOpeningElement(path) {
      if (t.isJSXIdentifier(path.node.name) && path.node.name.name.toLowerCase() === 'svg') {
        path.traverse(attrVisitor);
        path.traverse(styleAttrVisitor);
        path.traverse(hyphenToCamelVisitor);

        // add spread props
        path.node.attributes.push(t.jSXSpreadAttribute(t.memberExpression(t.thisExpression(), t.identifier('props'))));
      } else {
        // don't ignore style attr transformations for other nodes
        path.traverse(styleAttrVisitor);
        path.traverse(hyphenToCamelVisitor);
      }
    }
  };

  // returns
  // export default class SVG extends React.Component {
  //   render() {
  //     return ${input_svg_node}
  //   }
  // }
  var getExport = function getExport(svg) {
    var className = arguments.length <= 1 || arguments[1] === undefined ? 'SVG' : arguments[1];

    return t.exportDefaultDeclaration(t.classDeclaration(t.identifier(className), t.memberExpression(t.identifier('React'), t.identifier('Component')), t.classBody([t.classMethod('method', t.identifier('render'), [], t.blockStatement([t.returnStatement(svg)]))]), []));
  };

  // converts
  // <svg/>
  // to
  // import React from 'react';
  // export default class SVG extends React.Component { render() { <svg/> }}
  // after passing through other visitors
  var programVisitor = {
    Program: function Program(path) {
      if (path.node.body.length === 0) throw new Error('No Content in SVG file');
      if (path.node.body.length > 1) throw new Error('There is more than one root Element. We don\'t support this yet.');

      var node = path.node.body[0];
      if (!t.isExpressionStatement(node)) return;
      if (!t.isJSXElement(node.expression)) return;
      if (!t.isJSXIdentifier(node.expression.openingElement.name)) return;
      if (node.expression.openingElement.name.name !== 'svg') return;

      path.traverse(svgVisitor);

      // replace the entire node to
      // export default class extends React {
      //   render () {
      //     SVG_NODE
      //   }
      // }

      path.node.body[0] = getExport(node.expression);

      // add import react statement
      path.node.body.unshift(t.importDeclaration([t.importDefaultSpecifier(t.identifier('React'))], t.stringLiteral('react')));
    }
  };

  return {
    visitor: programVisitor
  };
};

var _cssToObj = require('./css-to-obj');

var _cssToObj2 = _interopRequireDefault(_cssToObj);

var _hyphenToCamel = require('./hyphen-to-camel');

var _hyphenToCamel2 = _interopRequireDefault(_hyphenToCamel);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = exports['default'];